package # Dear CPAN, please don't index this
MyGlobalSubs;
use Devel::GlobalSub qw(test_a test_b);

sub test_a {
	return 'test_a OK';
}

sub test_b {
	return 'test_b OK';
}

1;
